.BG
.FN mixed.text.vector
.FN mixed.mtext.vector
.TL
Mixed-text versions text and mtext - vectorized interface
.DN
Plot text with mixed fonts and character sizes, 
sub- and super-scripts, using vectors of control parameters.
Used with `postscript()' device driver or screen device drivers.
.CS
mixed.text.vector(x, y, font, texts, offset, raise, cex, srt=0, 
  slope, noprint=F, fill.zero=T)

mixed.mtext.vector(side = 3, line = 0, outer. = F, at, font, texts, 
  offset, raise, cex, srt=0, slope, noprint=F, fill.zero=T)
.AG x
Numeric scalar, x-position of start of string.
.AG y
Numeric scalar, y-position of start of string.
.AG side
side (1,2,3,4 for bottom, left, top, or right).
.AG line
line (measured out from the plot in units of standard-sized
character heights).
The default values of graphical parameter `mar' allow
characters can be placed at values of `line' less than or equal to
4 on the bottom, 3 on left and top, and 1 on the right.
.AG outer
logical flag, should plotting be done in outer margin?
.AG at
optional vector of positions at which `text' is to be
plotted.  If `side' is 1 or 3, `at' will represent x-coordinates.
If `side' is 2 or 4, `at' will represent y-coordinates.
`at' can be used for constructing specialized
axis labels, etc.
.AG font
Vector of font numbers for each text segment.
.AG texts
Character vector of text segments.
.AG offset
Horizontal offset in em units before each segment (negative to backspace);
if of length 1, offset before first segment only. 
Note that offsets are useful for kerning (adding or subtracting
space where different fonts meet up), for backspacing (e.g. putting a
subscript beneath a superscript), for centering text, and for adjusting
spacing when character sizes differ from those in the font file, e.g.
when using the ISO Latin preamble.
.AG raise
Height relative to baseline of each segment (up or down).
.AG cex
Character expansion for each segment relative to default cex.
.AG srt
String rotation angle.
.AG slope
Alternative method of expressing string rotation, as slope of the
baseline of the text in user coordinates (useful for labeling a slanted
line).
.AG noprint
Logical: if `noprint=T', nothing will be plotted.  Used to determine
length of plotted string for centering purposes.
.AG fill.zero
Logical: if `T', any ASCII character whose width is not given in the font
metric file will be assumed to be the same width as the letter `"A"' in that
font.  Useful when using extended character sets (e.g. ps.preamble.ISO.LATIN)
which are not in the standard metric files ; 
some trial-and-error horizontal adjustment
may be needed with these characters.
.RT
Length of plotted string in em units (width of letter `"m"');
by backspacing half this amount at the beginning of the text (using offset
argument), the string
can be centered at the (x,y) position.
.SE
The strings are plotted with specified fonts and locations on the
postscript plot.  Note that some useful characters (some math signs,
accented letters, and superscripts) are available using ISO-Latin
extended fonts:  see help for `ps.show.fonts()', and for
`ps.setfont.latin1' in S-PLUS.

This code is designed primarily for postscript plots.  By default,
spacing for a screen device will be an approximation to the values
required to give the desired appearance when the plot is printed using
the `"print"' button on the window.  Spacings that may have a better
appearance on screen can be obtained by the option setting command
`"options(mixed.text.screen=T)"'.  However, due to the limitations and
varied characteristics of screen graphics devices, the results will not
be consistent.

.EX
> postscript()
> plot(1:10,1:10,type="n")
> mixed.text.vector(2,3,c(1,4,13,3,1,13,1,4),
    c("Plot of: ","az","b","t","1","S","p","K"),       
    offset=c(0,0,.2,0,-.3,+.3,0,0),raise=c(0,0,0,.5,-.5,0,0,-.5),
    cex=c(1,1,1,.7,.7,1.3,1,.5),srt=45)
.SA
`ps.show.fonts', `fontdemo', `mixed.text'
.KW aplot
.WR
